/* display-page.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from display-page.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <gdk/gdk.h>
#include <float.h>
#include <math.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include <cairo.h>


#define BOXES_TYPE_DISPLAY_TOOLBAR (boxes_display_toolbar_get_type ())
#define BOXES_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar))
#define BOXES_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))
#define BOXES_IS_DISPLAY_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_IS_DISPLAY_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_TOOLBAR))
#define BOXES_DISPLAY_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarClass))

typedef struct _BoxesDisplayToolbar BoxesDisplayToolbar;
typedef struct _BoxesDisplayToolbarClass BoxesDisplayToolbarClass;
typedef struct _BoxesDisplayToolbarPrivate BoxesDisplayToolbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;
typedef struct _BoxesDisplayPagePrivate BoxesDisplayPagePrivate;

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_APP_PAGE (boxes_app_page_get_type ())

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block6Data Block6Data;

struct _BoxesDisplayToolbar {
	GtkToolbar parent_instance;
	BoxesDisplayToolbarPrivate * priv;
};

struct _BoxesDisplayToolbarClass {
	GtkToolbarClass parent_class;
};

struct _BoxesDisplayToolbarPrivate {
	GtkLabel* label;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesDisplayPage {
	GObject parent_instance;
	BoxesDisplayPagePrivate * priv;
};

struct _BoxesDisplayPageClass {
	GObjectClass parent_class;
};

struct _BoxesDisplayPagePrivate {
	GtkOverlay* overlay;
	GtkEventBox* event_box;
	GtkBox* box;
	BoxesDisplayToolbar* overlay_toolbar;
	BoxesDisplayToolbar* toolbar;
	guint toolbar_hide_id;
	gulong display_id;
	gulong cursor_id;
	BoxesDisplay* display;
	gulong display_can_grab_id;
	gulong display_grabbed_id;
};

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_APP_PAGE_MAIN,
	BOXES_APP_PAGE_DISPLAY
} BoxesAppPage;

struct _Block6Data {
	int _ref_count_;
	BoxesDisplayPage * self;
	gulong draw_id;
	GtkWidget* widget;
};


static gpointer boxes_display_toolbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;
static gpointer boxes_display_page_parent_class = NULL;

GType boxes_display_toolbar_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_TOOLBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbarPrivate))
enum  {
	BOXES_DISPLAY_TOOLBAR_DUMMY_PROPERTY,
	BOXES_DISPLAY_TOOLBAR_TITLE
};
BoxesDisplayToolbar* boxes_display_toolbar_new (void);
BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type);
#define BOXES_TOPBAR_height ((guint) 50)
static void __lambda22_ (BoxesDisplayToolbar* self, GtkButton* button);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda22__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda23_ (BoxesDisplayToolbar* self, GtkButton* button);
gboolean boxes_app_get_fullscreen (BoxesApp* self);
void boxes_app_set_fullscreen (BoxesApp* self, gboolean value);
static void ___lambda23__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda24_ (BoxesDisplayToolbar* self, GtkButton* button);
static void ___lambda24__gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_display_toolbar_set_title (BoxesDisplayToolbar* self, const gchar* value);
static void boxes_display_toolbar_finalize (GObject* obj);
static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_display_get_type (void) G_GNUC_CONST;
#define BOXES_DISPLAY_PAGE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPagePrivate))
enum  {
	BOXES_DISPLAY_PAGE_DUMMY_PROPERTY,
	BOXES_DISPLAY_PAGE_WIDGET
};
static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self);
BoxesDisplayPage* boxes_display_page_new (void);
BoxesDisplayPage* boxes_display_page_construct (GType object_type);
static gboolean __lambda25_ (BoxesDisplayPage* self, GdkEvent* event);
static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static gboolean _____lambda26_ (BoxesDisplayPage* self);
static gboolean ______lambda26__gsource_func (gpointer self);
static gboolean ___lambda25__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
static gboolean __lambda27_ (BoxesDisplayPage* self, GdkEventWindowState* event);
static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self);
static gboolean ___lambda27__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self);
void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height);
static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self);
void boxes_display_page_show (BoxesDisplayPage* self);
GType boxes_app_page_get_type (void) G_GNUC_CONST;
void boxes_display_page_update_title (BoxesDisplayPage* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
gchar* boxes_collection_item_get_title (BoxesCollectionItem* self);
static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self);
void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget);
static Block6Data* block6_data_ref (Block6Data* _data6_);
static void block6_data_unref (void * _userdata_);
GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self);
static void __lambda28_ (BoxesDisplayPage* self);
static void ___lambda28__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda29_ (BoxesDisplayPage* self);
static void ___lambda29__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean __lambda30_ (BoxesDisplayPage* self, GdkEvent* event);
static gboolean ___lambda30__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self);
static gboolean __lambda31_ (Block6Data* _data6_);
static void __lambda32_ (Block6Data* _data6_);
static void ___lambda32__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static gboolean ___lambda31__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
GtkWidget* boxes_display_page_get_widget (BoxesDisplayPage* self);
gboolean boxes_display_get_can_grab_mouse (BoxesDisplay* self);
gboolean boxes_display_get_mouse_grabbed (BoxesDisplay* self);
static void boxes_display_page_finalize (GObject* obj);
static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


static void __lambda22_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 378 "display-page.c"
}


static void ___lambda22__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda22_ (self, _sender);
#line 385 "display-page.c"
}


static void __lambda23_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_app_set_fullscreen (_tmp0_, !_tmp3_);
#line 406 "display-page.c"
}


static void ___lambda23__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda23_ (self, _sender);
#line 413 "display-page.c"
}


static void __lambda24_ (BoxesDisplayToolbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (button != NULL);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_PROPERTIES);
#line 425 "display-page.c"
}


static void ___lambda24__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda24_ (self, _sender);
#line 432 "display-page.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_construct (GType object_type) {
	BoxesDisplayToolbar * self = NULL;
	GtkStyleContext* _tmp0_ = NULL;
	GtkToolItem* _tmp1_;
	GtkToolItem* left_group;
	GtkToolItem* _tmp2_;
	GtkToolItem* center_group;
	GtkToolItem* _tmp3_;
	GtkToolItem* right_group;
	GtkSizeGroup* _tmp4_;
	GtkSizeGroup* size_group;
	GtkBox* _tmp5_;
	GtkBox* left_box;
	GtkButton* _tmp6_;
	GtkButton* back;
	GtkImage* _tmp7_;
	GtkImage* _tmp8_;
	GtkStyleContext* _tmp9_ = NULL;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	GtkLabel* _tmp12_;
	GtkBox* _tmp13_;
	GtkBox* right_box;
	GtkButton* _tmp14_;
	GtkButton* btn;
	GtkImage* _tmp15_;
	GtkImage* _tmp16_;
	GtkStyleContext* _tmp17_ = NULL;
	GtkButton* _tmp18_;
	GtkButton* props;
	GtkImage* _tmp19_;
	GtkImage* _tmp20_;
	GtkStyleContext* _tmp21_ = NULL;
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayToolbar*) g_object_new (object_type, NULL);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_toolbar_set_icon_size ((GtkToolbar*) self, (gint) GTK_ICON_SIZE_MENU);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp0_, GTK_STYLE_CLASS_MENUBAR);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_toolbar_set_show_arrow ((GtkToolbar*) self, FALSE);
#line 17 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_size_request ((GtkWidget*) self, -1, (gint) BOXES_TOPBAR_height);
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = gtk_tool_item_new ();
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp1_);
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	left_group = _tmp1_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_toolbar_insert ((GtkToolbar*) self, left_group, 0);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = gtk_tool_item_new ();
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp2_);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	center_group = _tmp2_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_tool_item_set_expand (center_group, TRUE);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_toolbar_insert ((GtkToolbar*) self, center_group, -1);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_tool_item_new ();
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp3_);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	right_group = _tmp3_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_toolbar_insert ((GtkToolbar*) self, right_group, -1);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	size_group = _tmp4_;
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_size_group_add_widget (size_group, (GtkWidget*) left_group);
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_size_group_add_widget (size_group, (GtkWidget*) right_group);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp5_);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	left_box = _tmp5_;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_valign ((GtkWidget*) left_box, GTK_ALIGN_CENTER);
#line 35 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) left_group, (GtkWidget*) left_box);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = (GtkButton*) gtk_button_new ();
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp6_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	back = _tmp6_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = (GtkImage*) gtk_image_new_from_icon_name ("go-previous-symbolic", GTK_ICON_SIZE_MENU);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp7_);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp8_ = _tmp7_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) back, (GtkWidget*) _tmp8_);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp8_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) back);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp9_, "raised");
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (back, "clicked", (GCallback) ___lambda22__gtk_button_clicked, self, 0);
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (left_box, (GtkWidget*) back, FALSE, FALSE, (guint) 0);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp10_ = (GtkLabel*) gtk_label_new ("Display");
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp10_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->label);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->label = _tmp10_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp11_ = self->priv->label;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_label_set_use_markup (_tmp11_, TRUE);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->priv->label;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) center_group, (GtkWidget*) _tmp12_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp13_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp13_);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	right_box = _tmp13_;
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_valign ((GtkWidget*) right_box, GTK_ALIGN_CENTER);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) right_group, (GtkWidget*) right_box);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp14_ = (GtkButton*) gtk_button_new ();
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp14_);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	btn = _tmp14_;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp15_ = (GtkImage*) gtk_image_new_from_icon_name ("view-fullscreen-symbolic", GTK_ICON_SIZE_MENU);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp15_);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp16_ = _tmp15_;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) btn, (GtkWidget*) _tmp16_);
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp16_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp17_ = gtk_widget_get_style_context ((GtkWidget*) btn);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp17_, "raised");
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (btn, "clicked", (GCallback) ___lambda23__gtk_button_clicked, self, 0);
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (right_box, (GtkWidget*) btn, FALSE, FALSE, (guint) 0);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp18_ = (GtkButton*) gtk_button_new ();
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp18_);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	props = _tmp18_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp19_ = (GtkImage*) gtk_image_new_from_icon_name ("utilities-system-monitor-symbolic", GTK_ICON_SIZE_MENU);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp19_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp20_ = _tmp19_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) props, (GtkWidget*) _tmp20_);
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp20_);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp21_ = gtk_widget_get_style_context ((GtkWidget*) props);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp21_, "raised");
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_connect_object (props, "clicked", (GCallback) ___lambda24__gtk_button_clicked, self, 0);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (right_box, (GtkWidget*) props, FALSE, FALSE, (guint) 0);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (props);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (btn);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (right_box);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (back);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (left_box);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (size_group);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (right_group);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (center_group);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (left_group);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return self;
#line 643 "display-page.c"
}


BoxesDisplayToolbar* boxes_display_toolbar_new (void) {
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return boxes_display_toolbar_construct (BOXES_TYPE_DISPLAY_TOOLBAR);
#line 650 "display-page.c"
}


void boxes_display_toolbar_set_title (BoxesDisplayToolbar* self, const gchar* value) {
	GtkLabel* _tmp0_;
	const gchar* _tmp1_;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->label;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = value;
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_label_set_markup (_tmp0_, _tmp1_);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_notify ((GObject *) self, "title");
#line 667 "display-page.c"
}


static void boxes_display_toolbar_class_init (BoxesDisplayToolbarClass * klass) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayToolbarPrivate));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_display_toolbar_set_property;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_toolbar_finalize;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_TOOLBAR_TITLE, g_param_spec_string ("title", "title", "title", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_WRITABLE));
#line 682 "display-page.c"
}


static void boxes_display_toolbar_instance_init (BoxesDisplayToolbar * self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_TOOLBAR_GET_PRIVATE (self);
#line 689 "display-page.c"
}


static void boxes_display_toolbar_finalize (GObject* obj) {
	BoxesDisplayToolbar * self;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->label);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_toolbar_parent_class)->finalize (obj);
#line 701 "display-page.c"
}


GType boxes_display_toolbar_get_type (void) {
	static volatile gsize boxes_display_toolbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_toolbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayToolbar), 0, (GInstanceInitFunc) boxes_display_toolbar_instance_init, NULL };
		GType boxes_display_toolbar_type_id;
		boxes_display_toolbar_type_id = g_type_register_static (GTK_TYPE_TOOLBAR, "BoxesDisplayToolbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_toolbar_type_id__volatile, boxes_display_toolbar_type_id);
	}
	return boxes_display_toolbar_type_id__volatile;
}


static void _vala_boxes_display_toolbar_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesDisplayToolbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_TOOLBAR, BoxesDisplayToolbar);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	switch (property_id) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		case BOXES_DISPLAY_TOOLBAR_TITLE:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		boxes_display_toolbar_set_title (self, g_value_get_string (value));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		break;
#line 728 "display-page.c"
		default:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		break;
#line 734 "display-page.c"
	}
}


static gboolean _____lambda26_ (BoxesDisplayPage* self) {
	gboolean result = FALSE;
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 749 "display-page.c"
}


static gboolean ______lambda26__gsource_func (gpointer self) {
	gboolean result;
	result = _____lambda26_ (self);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 758 "display-page.c"
}


static gboolean __lambda25_ (BoxesDisplayPage* self, GdkEvent* event) {
	gboolean result = FALSE;
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp6_;
	GdkEvent* _tmp21_;
	GdkEventType _tmp22_;
	GtkEventBox* _tmp23_;
	GtkWidget* _tmp24_ = NULL;
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 783 "display-page.c"
		GdkEvent* _tmp4_;
		GdkEventType _tmp5_;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp4_ = event;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_->type;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp5_ == GDK_MOTION_NOTIFY;
#line 792 "display-page.c"
	} else {
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 796 "display-page.c"
	}
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp0_;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 802 "display-page.c"
		GdkEvent* _tmp7_;
		GdkEventMotion _tmp8_;
		gdouble _tmp9_;
		gdouble y;
		gdouble _tmp10_;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp7_ = event;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp8_ = _tmp7_->motion;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp9_ = _tmp8_.y;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		y = _tmp9_;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp10_ = y;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		if (_tmp10_ <= ((gdouble) 0)) {
#line 820 "display-page.c"
			GdkEvent* _tmp11_;
			GdkEventMotion _tmp12_;
			GdkModifierType _tmp13_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			_tmp11_ = event;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			_tmp12_ = _tmp11_->motion;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			_tmp13_ = _tmp12_.state;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			if ((_tmp13_ & ((((((((((GDK_SHIFT_MASK | GDK_CONTROL_MASK) | GDK_MOD1_MASK) | GDK_SUPER_MASK) | GDK_HYPER_MASK) | GDK_META_MASK) | GDK_BUTTON1_MASK) | GDK_BUTTON2_MASK) | GDK_BUTTON3_MASK) | GDK_BUTTON4_MASK) | GDK_BUTTON5_MASK)) == 0) {
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				boxes_display_page_set_overlay_toolbar_visible (self, TRUE);
#line 836 "display-page.c"
			}
		} else {
			gboolean _tmp14_ = FALSE;
			gdouble _tmp15_;
			gboolean _tmp17_;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			_tmp15_ = y;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			if (_tmp15_ > ((gdouble) 5)) {
#line 846 "display-page.c"
				guint _tmp16_;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp16_ = self->priv->toolbar_hide_id;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp14_ = _tmp16_ == ((guint) 0);
#line 852 "display-page.c"
			} else {
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp14_ = FALSE;
#line 856 "display-page.c"
			}
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			_tmp17_ = _tmp14_;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			if (_tmp17_) {
#line 862 "display-page.c"
				BoxesApp* _tmp18_;
				guint _tmp19_;
				guint _tmp20_ = 0U;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				boxes_display_page_toolbar_event_stop (self);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp18_ = boxes_app_app;
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp19_ = _tmp18_->duration;
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				_tmp20_ = g_timeout_add_full (G_PRIORITY_DEFAULT, _tmp19_, ______lambda26__gsource_func, g_object_ref (self), g_object_unref);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
				self->priv->toolbar_hide_id = _tmp20_;
#line 876 "display-page.c"
			}
		}
	}
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp21_ = event;
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp22_ = _tmp21_->type;
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp22_ == GDK_GRAB_BROKEN) {
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		result = FALSE;
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		return result;
#line 890 "display-page.c"
	}
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp23_ = self->priv->event_box;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp24_ = gtk_bin_get_child ((GtkBin*) _tmp23_);
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp24_ != NULL) {
#line 898 "display-page.c"
		GtkEventBox* _tmp25_;
		GtkWidget* _tmp26_ = NULL;
		GdkEvent* _tmp27_;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp25_ = self->priv->event_box;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp26_ = gtk_bin_get_child ((GtkBin*) _tmp25_);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp27_ = event;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		gtk_widget_event (_tmp26_, _tmp27_);
#line 910 "display-page.c"
	}
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 916 "display-page.c"
}


static gboolean ___lambda25__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = __lambda25_ (self, event);
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 925 "display-page.c"
}


static gboolean __lambda27_ (BoxesDisplayPage* self, GdkEventWindowState* event) {
	gboolean result = FALSE;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 939 "display-page.c"
}


static gboolean ___lambda27__gtk_widget_window_state_event (GtkWidget* _sender, GdkEventWindowState* event, gpointer self) {
	gboolean result;
	result = __lambda27_ (self, event);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 948 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_construct (GType object_type) {
	BoxesDisplayPage * self = NULL;
	GtkEventBox* _tmp0_;
	GtkEventBox* _tmp1_;
	GtkStyleContext* _tmp2_ = NULL;
	GtkEventBox* _tmp3_;
	GtkEventBox* _tmp4_;
	GtkEventBox* _tmp5_;
	BoxesDisplayToolbar* _tmp6_;
	GtkBox* _tmp7_;
	GtkBox* _tmp8_;
	BoxesDisplayToolbar* _tmp9_;
	GtkBox* _tmp10_;
	GtkEventBox* _tmp11_;
	GtkOverlay* _tmp12_;
	BoxesApp* _tmp13_;
	GtkApplicationWindow* _tmp14_;
	GtkOverlay* _tmp15_;
	GtkOverlay* _tmp16_;
	GtkBox* _tmp17_;
	BoxesDisplayToolbar* _tmp18_;
	BoxesDisplayToolbar* _tmp19_;
	GtkOverlay* _tmp20_;
	BoxesDisplayToolbar* _tmp21_;
	GtkOverlay* _tmp22_;
	GtkStyleContext* _tmp23_ = NULL;
	GtkOverlay* _tmp24_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = (BoxesDisplayPage*) g_object_new (object_type, NULL);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = (GtkEventBox*) gtk_event_box_new ();
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp0_);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->event_box = _tmp0_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = self->priv->event_box;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = gtk_widget_get_style_context ((GtkWidget*) _tmp1_);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp2_, "boxes-toplevel");
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->event_box;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events ((GtkWidget*) _tmp3_, (gint) (GDK_POINTER_MOTION_MASK | GDK_SCROLL_MASK));
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = self->priv->event_box;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_event_box_set_above_child (_tmp4_, TRUE);
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = self->priv->event_box;
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp5_, "event", (GCallback) ___lambda25__gtk_widget_event, self, 0);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = boxes_display_toolbar_new ();
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp6_);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->toolbar = _tmp6_;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp7_);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->box);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->box = _tmp7_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp8_ = self->priv->box;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp9_ = self->priv->toolbar;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (_tmp8_, (GtkWidget*) _tmp9_, FALSE, FALSE, (guint) 0);
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp10_ = self->priv->box;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp11_ = self->priv->event_box;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_box_pack_start (_tmp10_, (GtkWidget*) _tmp11_, TRUE, TRUE, (guint) 0);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp12_ = (GtkOverlay*) gtk_overlay_new ();
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp12_);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->overlay = _tmp12_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp13_ = boxes_app_app;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp14_ = _tmp13_->window;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_connect_object ((GtkWidget*) _tmp14_, "window-state-event", (GCallback) ___lambda27__gtk_widget_window_state_event, self, 0);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp15_ = self->priv->overlay;
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_set ((GtkWidget*) _tmp15_, "margin", 0, NULL);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp16_ = self->priv->overlay;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp17_ = self->priv->box;
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp16_, (GtkWidget*) _tmp17_);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp18_ = boxes_display_toolbar_new ();
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_ref_sink (_tmp18_);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->overlay_toolbar = _tmp18_;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp19_ = self->priv->overlay_toolbar;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp19_, GTK_ALIGN_START);
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp20_ = self->priv->overlay;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp21_ = self->priv->overlay_toolbar;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_overlay_add_overlay (_tmp20_, (GtkWidget*) _tmp21_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp22_ = self->priv->overlay;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp23_ = gtk_widget_get_style_context ((GtkWidget*) _tmp22_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_style_context_add_class (_tmp23_, "boxes-toplevel");
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp24_ = self->priv->overlay;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp24_);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return self;
#line 1089 "display-page.c"
}


BoxesDisplayPage* boxes_display_page_new (void) {
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return boxes_display_page_construct (BOXES_TYPE_DISPLAY_PAGE);
#line 1096 "display-page.c"
}


void boxes_display_page_get_size (BoxesDisplayPage* self, gint* width, gint* height) {
	gint _vala_width = 0;
	gint _vala_height = 0;
	gint tb_height = 0;
	BoxesApp* _tmp0_;
	GtkApplicationWindow* _tmp1_;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	BoxesApp* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->window;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_window_get_size ((GtkWindow*) _tmp1_, &_tmp2_, &_tmp3_);
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_vala_width = _tmp2_;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_vala_height = _tmp3_;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = boxes_app_app;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_app_get_fullscreen (_tmp4_);
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (!_tmp6_) {
#line 1131 "display-page.c"
		BoxesDisplayToolbar* _tmp7_;
		gint _tmp8_ = 0;
		gint _tmp9_;
		gint _tmp10_;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->toolbar;
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		gtk_widget_get_preferred_height ((GtkWidget*) _tmp7_, NULL, &_tmp8_);
#line 154 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		tb_height = _tmp8_;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp9_ = _vala_height;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp10_ = tb_height;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_vala_height = _tmp9_ - _tmp10_;
#line 1148 "display-page.c"
	}
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (width) {
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		*width = _vala_width;
#line 1154 "display-page.c"
	}
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (height) {
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		*height = _vala_height;
#line 1160 "display-page.c"
	}
}


static void boxes_display_page_update_toolbar_visible (BoxesDisplayPage* self) {
	gboolean _tmp0_ = FALSE;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp6_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_app_app;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_app_get_fullscreen (_tmp1_);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp3_) {
#line 1181 "display-page.c"
		gboolean _tmp4_;
		gboolean _tmp5_;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp4_ = boxes_display_page_get_can_grab_mouse (self);
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp5_ = _tmp4_;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = !_tmp5_;
#line 1190 "display-page.c"
	} else {
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1194 "display-page.c"
	}
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp0_;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp6_) {
#line 1200 "display-page.c"
		BoxesDisplayToolbar* _tmp7_;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp7_ = self->priv->toolbar;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp7_, FALSE);
#line 1206 "display-page.c"
	} else {
		BoxesDisplayToolbar* _tmp8_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp8_ = self->priv->toolbar;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		gtk_widget_set_visible ((GtkWidget*) _tmp8_, TRUE);
#line 1213 "display-page.c"
	}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 1217 "display-page.c"
}


static void boxes_display_page_set_overlay_toolbar_visible (BoxesDisplayPage* self, gboolean visible) {
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	gboolean _tmp5_;
	BoxesDisplayToolbar* _tmp6_;
	gboolean _tmp7_;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = visible;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp1_) {
#line 1233 "display-page.c"
		BoxesDisplayToolbar* _tmp2_;
		gboolean _tmp3_;
		gboolean _tmp4_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->toolbar;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp3_ = gtk_widget_get_visible ((GtkWidget*) _tmp2_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp4_ = _tmp3_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = _tmp4_;
#line 1245 "display-page.c"
	} else {
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp0_ = FALSE;
#line 1249 "display-page.c"
	}
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp0_;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp5_) {
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_debug ("display-page.vala:170: toolbar is visible, don't show overlay toolbar");
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		return;
#line 1259 "display-page.c"
	}
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->overlay_toolbar;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = visible;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp6_, _tmp7_);
#line 1267 "display-page.c"
}


static void boxes_display_page_toolbar_event_stop (BoxesDisplayPage* self) {
	guint _tmp0_;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->toolbar_hide_id;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((guint) 0)) {
#line 1279 "display-page.c"
		guint _tmp1_;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->toolbar_hide_id;
#line 183 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_source_remove (_tmp1_);
#line 1285 "display-page.c"
	}
#line 184 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->toolbar_hide_id = (guint) 0;
#line 1289 "display-page.c"
}


void boxes_display_page_show (BoxesDisplayPage* self) {
	BoxesApp* _tmp0_;
	GtkNotebook* _tmp1_;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->notebook;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_set (_tmp1_, "page", (gint) BOXES_APP_PAGE_DISPLAY, NULL);
#line 1304 "display-page.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return self ? g_object_ref (self) : NULL;
#line 1311 "display-page.c"
}


void boxes_display_page_update_title (BoxesDisplayPage* self) {
	BoxesApp* _tmp0_;
	BoxesCollectionItem* _tmp1_;
	BoxesMachine* _tmp2_;
	BoxesMachine* machine;
	BoxesMachine* _tmp3_;
	BoxesMachine* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* title;
	gboolean _tmp7_;
	gboolean _tmp8_;
	BoxesDisplayToolbar* _tmp12_;
	BoxesDisplayToolbar* _tmp13_;
	const gchar* _tmp14_;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = boxes_app_app;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->current_item;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp1_) : NULL);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	machine = _tmp2_;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = machine;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (_tmp3_ != NULL);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = machine;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = boxes_collection_item_get_title ((BoxesCollectionItem*) _tmp4_);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = _tmp5_;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	title = _tmp6_;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = boxes_display_page_get_grabbed (self);
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp8_ = _tmp7_;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp8_) {
#line 1358 "display-page.c"
		const gchar* _tmp9_ = NULL;
		const gchar* _tmp10_;
		gchar* _tmp11_ = NULL;
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp9_ = _ ("%s <b>(press Ctrl+Alt keys to ungrab)</b>");
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp10_ = title;
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp11_ = g_strdup_printf (_tmp9_, _tmp10_);
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_g_free0 (title);
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		title = _tmp11_;
#line 1372 "display-page.c"
	}
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->priv->overlay_toolbar;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp13_ = self->priv->toolbar;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp14_ = title;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_set_title (_tmp13_, _tmp14_);
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_toolbar_set_title (_tmp12_, _tmp14_);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_free0 (title);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (machine);
#line 1388 "display-page.c"
}


static Block6Data* block6_data_ref (Block6Data* _data6_) {
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_atomic_int_inc (&_data6_->_ref_count_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return _data6_;
#line 1397 "display-page.c"
}


static void block6_data_unref (void * _userdata_) {
	Block6Data* _data6_;
	_data6_ = (Block6Data*) _userdata_;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (g_atomic_int_dec_and_test (&_data6_->_ref_count_)) {
#line 1406 "display-page.c"
		BoxesDisplayPage * self;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		self = _data6_->self;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (_data6_->widget);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_g_object_unref0 (self);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_slice_free (Block6Data, _data6_);
#line 1416 "display-page.c"
	}
}


static void __lambda28_ (BoxesDisplayPage* self) {
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 1424 "display-page.c"
}


static void ___lambda28__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda28_ (self);
#line 1431 "display-page.c"
}


static void __lambda29_ (BoxesDisplayPage* self) {
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_toolbar_visible (self);
#line 1438 "display-page.c"
}


static void ___lambda29__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda29_ (self);
#line 1445 "display-page.c"
}


static gboolean __lambda30_ (BoxesDisplayPage* self, GdkEvent* event) {
	gboolean result = FALSE;
	GdkEvent* _tmp0_;
	GdkEventType _tmp1_;
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = event;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _tmp0_->type;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	switch (_tmp1_) {
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		case GDK_LEAVE_NOTIFY:
#line 1463 "display-page.c"
		{
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			break;
#line 1469 "display-page.c"
		}
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		case GDK_ENTER_NOTIFY:
#line 1473 "display-page.c"
		{
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			boxes_display_page_toolbar_event_stop (self);
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
			break;
#line 1479 "display-page.c"
		}
		default:
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		break;
#line 1484 "display-page.c"
	}
#line 228 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 228 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1490 "display-page.c"
}


static gboolean ___lambda30__gtk_widget_event (GtkWidget* _sender, GdkEvent* event, gpointer self) {
	gboolean result;
	result = __lambda30_ (self, event);
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1499 "display-page.c"
}


static void __lambda32_ (Block6Data* _data6_) {
	BoxesDisplayPage * self;
	GtkEventBox* _tmp0_;
	GdkWindow* _tmp1_ = NULL;
	GtkWidget* _tmp2_;
	GdkWindow* _tmp3_ = NULL;
	GdkCursor* _tmp4_;
	GdkCursor* _tmp5_;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = _data6_->self;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->event_box;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = gtk_widget_get_window ((GtkWidget*) _tmp0_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data6_->widget;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = gdk_window_get_cursor (_tmp3_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = _tmp4_;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gdk_window_set_cursor (_tmp1_, _tmp5_);
#line 1527 "display-page.c"
}


static void ___lambda32__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	__lambda32_ (self);
#line 1534 "display-page.c"
}


static gboolean __lambda31_ (Block6Data* _data6_) {
	BoxesDisplayPage * self;
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
	gulong _tmp1_;
	GtkWidget* _tmp2_;
	GdkWindow* _tmp3_ = NULL;
	gulong _tmp4_ = 0UL;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = _data6_->self;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = _data6_->widget;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _data6_->draw_id;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = _data6_->widget;
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = gtk_widget_get_window (_tmp2_);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = g_signal_connect_data ((GObject*) _tmp3_, "notify::cursor", (GCallback) ___lambda32__g_object_notify, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 235 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->cursor_id = _tmp4_;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = FALSE;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1566 "display-page.c"
}


static gboolean ___lambda31__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda31_ (self);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1575 "display-page.c"
}


void boxes_display_page_show_display (BoxesDisplayPage* self, BoxesDisplay* display, GtkWidget* widget) {
	Block6Data* _data6_;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_ = NULL;
	GtkWidget* _tmp3_;
	BoxesDisplay* _tmp4_;
	BoxesDisplay* _tmp5_;
	BoxesDisplay* _tmp6_;
	gulong _tmp7_ = 0UL;
	BoxesDisplay* _tmp8_;
	gulong _tmp9_ = 0UL;
	GtkWidget* _tmp10_;
	GtkWidget* _tmp11_;
	gint _tmp12_ = 0;
	GtkEventBox* _tmp13_;
	GtkWidget* _tmp14_;
	GtkEventBox* _tmp15_;
	GtkWidget* _tmp16_;
	gulong _tmp17_ = 0UL;
	GtkWidget* _tmp18_;
	gulong _tmp19_ = 0UL;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (self != NULL);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (display != NULL);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_if_fail (widget != NULL);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_ = g_slice_new0 (Block6Data);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_->_ref_count_ = 1;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_->self = g_object_ref (self);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = widget;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_->widget = _tmp1_;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = boxes_display_page_remove_display (self);
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = _tmp2_;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (_tmp3_);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp4_ = display;
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 205 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->display = _tmp5_;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = display;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = g_signal_connect_object ((GObject*) _tmp6_, "notify::mouse-grabbed", (GCallback) ___lambda28__g_object_notify, self, 0);
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->display_grabbed_id = _tmp7_;
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp8_ = display;
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp9_ = g_signal_connect_object ((GObject*) _tmp8_, "notify::can-grab-mouse", (GCallback) ___lambda29__g_object_notify, self, 0);
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->display_can_grab_id = _tmp9_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_set_overlay_toolbar_visible (self, FALSE);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_update_title (self);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp10_ = _data6_->widget;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp11_ = _data6_->widget;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp12_ = gtk_widget_get_events (_tmp11_);
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_set_events (_tmp10_, _tmp12_ & (~GDK_POINTER_MOTION_MASK));
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp13_ = self->priv->event_box;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp14_ = _data6_->widget;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_container_add ((GtkContainer*) _tmp13_, _tmp14_);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp15_ = self->priv->event_box;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp15_);
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp16_ = _data6_->widget;
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp17_ = g_signal_connect_object (_tmp16_, "event", (GCallback) ___lambda30__gtk_widget_event, self, 0);
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv->display_id = _tmp17_;
#line 231 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_->draw_id = (gulong) 0;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp18_ = _data6_->widget;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp19_ = g_signal_connect_data (_tmp18_, "draw", (GCallback) ___lambda31__gtk_widget_draw, block6_data_ref (_data6_), (GClosureNotify) block6_data_unref, 0);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_->draw_id = _tmp19_;
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_show (self);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	block6_data_unref (_data6_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_data6_ = NULL;
#line 1687 "display-page.c"
}


GtkWidget* boxes_display_page_remove_display (BoxesDisplayPage* self) {
	GtkWidget* result = NULL;
	gulong _tmp0_;
	gulong _tmp3_;
	GtkEventBox* _tmp6_;
	GtkWidget* _tmp7_ = NULL;
	GtkWidget* _tmp8_;
	GtkWidget* widget;
	gulong _tmp9_;
	gulong _tmp12_;
	GtkWidget* _tmp16_;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->display_grabbed_id;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp0_ != ((gulong) 0)) {
#line 1708 "display-page.c"
		BoxesDisplay* _tmp1_;
		gulong _tmp2_;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp1_ = self->priv->display;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp2_ = self->priv->display_grabbed_id;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp1_, _tmp2_);
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		self->priv->display_grabbed_id = (gulong) 0;
#line 1719 "display-page.c"
	}
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp3_ = self->priv->display_can_grab_id;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp3_ != ((gulong) 0)) {
#line 1725 "display-page.c"
		BoxesDisplay* _tmp4_;
		gulong _tmp5_;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp4_ = self->priv->display;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp5_ = self->priv->display_can_grab_id;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp4_, _tmp5_);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		self->priv->display_can_grab_id = (gulong) 0;
#line 1736 "display-page.c"
	}
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp6_ = self->priv->event_box;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp7_ = gtk_bin_get_child ((GtkBin*) _tmp6_);
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	widget = _tmp8_;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp9_ = self->priv->display_id;
#line 258 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp9_ != ((gulong) 0)) {
#line 1750 "display-page.c"
		GtkWidget* _tmp10_;
		gulong _tmp11_;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp10_ = widget;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp11_ = self->priv->display_id;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp10_, _tmp11_);
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		self->priv->display_id = (gulong) 0;
#line 1761 "display-page.c"
	}
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp12_ = self->priv->cursor_id;
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp12_ != ((gulong) 0)) {
#line 1767 "display-page.c"
		GtkWidget* _tmp13_;
		GdkWindow* _tmp14_ = NULL;
		gulong _tmp15_;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp13_ = widget;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp14_ = gtk_widget_get_window (_tmp13_);
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp15_ = self->priv->cursor_id;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_signal_handler_disconnect ((GObject*) _tmp14_, _tmp15_);
#line 264 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		self->priv->cursor_id = (gulong) 0;
#line 1781 "display-page.c"
	}
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp16_ = widget;
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	if (_tmp16_ != NULL) {
#line 1787 "display-page.c"
		GtkEventBox* _tmp17_;
		GtkWidget* _tmp18_;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp17_ = self->priv->event_box;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		_tmp18_ = widget;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		gtk_container_remove ((GtkContainer*) _tmp17_, _tmp18_);
#line 1796 "display-page.c"
	}
#line 270 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = widget;
#line 270 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1802 "display-page.c"
}


GtkWidget* boxes_display_page_get_widget (BoxesDisplayPage* self) {
	GtkWidget* result;
	GtkOverlay* _tmp0_;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->overlay;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = (GtkWidget*) _tmp0_;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1817 "display-page.c"
}


static gboolean boxes_display_page_get_can_grab_mouse (BoxesDisplayPage* self) {
	gboolean result;
	BoxesDisplay* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->display;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_display_get_can_grab_mouse (_tmp0_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = _tmp2_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1838 "display-page.c"
}


static gboolean boxes_display_page_get_grabbed (BoxesDisplayPage* self) {
	gboolean result;
	BoxesDisplay* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp0_ = self->priv->display;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp1_ = boxes_display_get_mouse_grabbed (_tmp0_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_tmp2_ = _tmp1_;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	result = _tmp2_;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	return result;
#line 1859 "display-page.c"
}


static void boxes_display_page_class_init (BoxesDisplayPageClass * klass) {
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_parent_class = g_type_class_peek_parent (klass);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_type_class_add_private (klass, sizeof (BoxesDisplayPagePrivate));
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_display_page_get_property;
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_display_page_finalize;
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_DISPLAY_PAGE_WIDGET, g_param_spec_object ("widget", "widget", "widget", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1874 "display-page.c"
}


static void boxes_display_page_instance_init (BoxesDisplayPage * self) {
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self->priv = BOXES_DISPLAY_PAGE_GET_PRIVATE (self);
#line 1881 "display-page.c"
}


static void boxes_display_page_finalize (GObject* obj) {
	BoxesDisplayPage * self;
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	boxes_display_page_toolbar_event_stop (self);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay);
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->event_box);
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->box);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->overlay_toolbar);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->toolbar);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	_g_object_unref0 (self->priv->display);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	G_OBJECT_CLASS (boxes_display_page_parent_class)->finalize (obj);
#line 1905 "display-page.c"
}


GType boxes_display_page_get_type (void) {
	static volatile gsize boxes_display_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_display_page_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDisplayPageClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_display_page_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDisplayPage), 0, (GInstanceInitFunc) boxes_display_page_instance_init, NULL };
		GType boxes_display_page_type_id;
		boxes_display_page_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDisplayPage", &g_define_type_info, 0);
		g_once_init_leave (&boxes_display_page_type_id__volatile, boxes_display_page_type_id);
	}
	return boxes_display_page_type_id__volatile;
}


static void _vala_boxes_display_page_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesDisplayPage * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
	switch (property_id) {
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		case BOXES_DISPLAY_PAGE_WIDGET:
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		g_value_set_object (value, boxes_display_page_get_widget (self));
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		break;
#line 1932 "display-page.c"
		default:
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/display-page.vala"
		break;
#line 1938 "display-page.c"
	}
}



